MODULE trcini
   !!======================================================================
   !!                         ***  MODULE trcini  ***
   !! TOP :   Manage the passive tracer initialization
   !!======================================================================
   !! History :    -   !  2000-04  (O. Aumont, M.A. Foujols)  original code
   !!             1.0  !  2005-03  (O. Aumont, A. El Moussaoui) F90
   !!              -   !  2005-10  (C. Ethe) Module
   !!----------------------------------------------------------------------
   !!   trc_ini :   Initialization for passive tracer
   !!----------------------------------------------------------------------
   USE par_trc         ! TOP parameters
   USE trcini_cfc      ! CFC     initialisation
   USE trcini_lobster  ! LOBSTER initialisation
   USE trcini_pisces   ! PISCES  initialisation
   USE trcini_my_trc   ! MY_TRC  initialisation

   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_ini   ! called by ???

   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Header:$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_ini
      !!-------------------------------------------------------------------
      !!                    ***  ROUTINE trc_ini  ***
      !!              
      !! ** Purpose :   Initialization of passive tracer to zero
      !!
      !! ** Method  :   call the initialisation of each defined tracer
      !!             model (LOBSTER, PISCES, CFC, MY_TRC)
      !!-------------------------------------------------------------------

      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) 'trc_ini : initial set up of the tracer models'
      IF(lwp) WRITE(numout,*) '~~~~~~~'
      !
      IF( lk_trc_lobster ) THEN   ;   CALL trc_ini_lobster      ! LOBSTER bio-model
      ELSE                        ;   IF(lwp) WRITE(numout,*) '          LOBSTER not used'
      ENDIF

      IF( lk_trc_pisces  ) THEN   ;   CALL trc_init_pisces      ! PISCES  bio-model
      ELSE                        ;   IF(lwp) WRITE(numout,*) '          PISCES not used'
      ENDIF

      IF( lk_trc_cfc     ) THEN   ;   CALL trc_init_cfc         ! CFC     tracers
      ELSE                        ;   IF(lwp) WRITE(numout,*) '          CFC not used'
      ENDIF

      IF( lk_trc_my_trc  ) THEN   ;   CALL trc_init_my_trc      ! MY_TRC  tracers
      ELSE                        ;   IF(lwp) WRITE(numout,*) '          MY_TRC not used'
      ENDIF
      !
   END SUBROUTINE trc_ini

   !!======================================================================
END MODULE trcini
